/* 45.4.0.0 - 45.7.255.255 */
{ 755236864UL, 4294705152UL, "whois.lacnic.net" },
/* 45.8.0.0 - 45.15.255.255 */
{ 755499008UL, 4294443008UL, "whois.ripe.net" },
/* 45.64.0.0 - 45.65.15.255 */
{ 759234560UL, 4294963200UL, "whois.apnic.net" },
{ 759169024UL, 4294901760UL, "whois.apnic.net" },
/* 45.65.16.0 - 45.65.63.255 */
{ 759238656UL, 4294963200UL, "whois.apnic.net" },
{ 759242752UL, 4294959104UL, "whois.apnic.net" },
/* 45.65.64.0 - 45.65.127.255 */
{ 759250944UL, 4294950912UL, "whois.ripe.net" },
/* 45.65.128.0 - 45.65.255.255 */
{ 759267328UL, 4294934528UL, "whois.lacnic.net" },
/* 45.66.0.0 - 45.67.255.255 */
{ 759300096UL, 4294836224UL, "whois.ripe.net" },
/* 45.68.0.0 - 45.71.255.255 */
{ 759431168UL, 4294705152UL, "whois.lacnic.net" },
/* 45.80.0.0 - 45.95.255.255 */
{ 760217600UL, 4293918720UL, "whois.ripe.net" },
/* 45.96.0.0 - 45.111.255.255 */
{ 761266176UL, 4293918720UL, "whois.afrinic.net" },
/* 45.112.0.0 - 45.127.255.255 */
{ 762314752UL, 4293918720UL, "whois.apnic.net" },
/* 45.128.0.0 - 45.159.255.255 */
{ 763363328UL, 4292870144UL, "whois.ripe.net" },
/* 45.160.0.0 - 45.191.255.255 */
{ 765460480UL, 4292870144UL, "whois.lacnic.net" },
/* 45.192.0.0 - 45.222.255.255 */
{ 767557632UL, 4293918720UL, "whois.afrinic.net" },
{ 768606208UL, 4294443008UL, "whois.afrinic.net" },
{ 769130496UL, 4294705152UL, "whois.afrinic.net" },
{ 769392640UL, 4294836224UL, "whois.afrinic.net" },
{ 769523712UL, 4294901760UL, "whois.afrinic.net" },
/* 45.224.0.0 - 45.239.255.255 */
{ 769654784UL, 4293918720UL, "whois.lacnic.net" },
/* 45.240.0.0 - 45.247.255.255 */
{ 770703360UL, 4294443008UL, "whois.afrinic.net" },
/* 45.248.0.0 - 45.255.255.255 */
{ 771227648UL, 4294443008UL, "whois.apnic.net" },
/* 66.251.128.0 - 66.251.191.255 */
{ 1123778560UL, 4294950912UL, "whois.afrinic.net" },
/* 72.44.16.0 - 72.44.31.255 */
{ 1210847232UL, 4294963200UL, "whois.lacnic.net" },
/* 128.201.0.0 - 128.201.255.255 */
{ 2160656384UL, 4294901760UL, "whois.lacnic.net" },
/* 131.196.0.0 - 131.196.255.255 */
{ 2210660352UL, 4294901760UL, "whois.lacnic.net" },
/* 137.59.0.0 - 137.59.255.255 */
{ 2302345216UL, 4294901760UL, "whois.apnic.net" },
/* 139.5.0.0 - 139.5.255.255 */
{ 2332360704UL, 4294901760UL, "whois.apnic.net" },
/* 139.26.0.0 - 139.26.255.255 */
{ 2333736960UL, 4294901760UL, "whois.afrinic.net" },
/* 144.48.0.0 - 144.48.255.255 */
{ 2419064832UL, 4294901760UL, "whois.apnic.net" },
/* 146.196.32.0 - 146.196.127.255 */
{ 2462326784UL, 4294959104UL, "whois.apnic.net" },
{ 2462334976UL, 4294950912UL, "whois.apnic.net" },
/* 146.196.128.0 - 146.196.255.255 */
{ 2462351360UL, 4294934528UL, "whois.afrinic.net" },
/* 147.78.0.0 - 147.78.255.255 */
{ 2471362560UL, 4294901760UL, "whois.ripe.net" },
/* 149.248.0.0 - 149.248.255.255 */
{ 2516058112UL, 4294901760UL, "whois.arin.net" },
/* 152.89.0.0 - 152.89.255.255 */
{ 2555969536UL, 4294901760UL, "whois.ripe.net" },
/* 157.119.0.0 - 157.119.255.255 */
{ 2641821696UL, 4294901760UL, "whois.apnic.net" },
/* 160.19.20.0 - 160.19.23.255 */
{ 2685604864UL, 4294966272UL, "whois.apnic.net" },
/* 160.19.36.0 - 160.19.39.255 */
{ 2685608960UL, 4294966272UL, "whois.afrinic.net" },
/* 160.19.44.0 - 160.19.47.255 */
{ 2685611008UL, 4294966272UL, "whois.lacnic.net" },
/* 160.19.48.0 - 160.19.55.255 */
{ 2685612032UL, 4294965248UL, "whois.apnic.net" },
/* 160.19.60.0 - 160.19.63.255 */
{ 2685615104UL, 4294966272UL, "whois.afrinic.net" },
/* 160.19.64.0 - 160.19.67.255 */
{ 2685616128UL, 4294966272UL, "whois.apnic.net" },
/* 160.19.92.0 - 160.19.95.255 */
{ 2685623296UL, 4294966272UL, "whois.ripe.net" },
/* 160.19.96.0 - 160.19.103.255 */
{ 2685624320UL, 4294965248UL, "whois.afrinic.net" },
/* 160.19.112.0 - 160.19.143.255 */
{ 2685628416UL, 4294963200UL, "whois.afrinic.net" },
{ 2685632512UL, 4294963200UL, "whois.afrinic.net" },
/* 160.19.152.0 - 160.19.155.255 */
{ 2685638656UL, 4294966272UL, "whois.afrinic.net" },
/* 160.19.168.0 - 160.19.175.255 */
{ 2685642752UL, 4294965248UL, "whois.lacnic.net" },
/* 160.19.180.0 - 160.19.183.255 */
{ 2685645824UL, 4294966272UL, "whois.ripe.net" },
/* 160.19.188.0 - 160.19.191.255 */
{ 2685647872UL, 4294966272UL, "whois.afrinic.net" },
/* 160.19.192.0 - 160.19.199.255 */
{ 2685648896UL, 4294965248UL, "whois.afrinic.net" },
/* 160.19.200.0 - 160.19.203.255 */
{ 2685650944UL, 4294966272UL, "whois.lacnic.net" },
/* 160.19.208.0 - 160.19.223.255 */
{ 2685652992UL, 4294963200UL, "whois.apnic.net" },
/* 160.19.224.0 - 160.19.227.255 */
{ 2685657088UL, 4294966272UL, "whois.apnic.net" },
/* 160.19.232.0 - 160.19.239.255 */
{ 2685659136UL, 4294965248UL, "whois.afrinic.net" },
/* 160.19.240.0 - 160.19.255.255 */
{ 2685661184UL, 4294963200UL, "whois.lacnic.net" },
/* 160.20.0.0 - 160.20.15.255 */
{ 2685665280UL, 4294963200UL, "whois.apnic.net" },
/* 160.20.20.0 - 160.20.23.255 */
{ 2685670400UL, 4294966272UL, "whois.lacnic.net" },
/* 160.20.24.0 - 160.20.31.255 */
{ 2685671424UL, 4294965248UL, "whois.afrinic.net" },
/* 160.20.32.0 - 160.20.35.255 */
{ 2685673472UL, 4294966272UL, "whois.lacnic.net" },
/* 160.20.40.0 - 160.20.47.255 */
{ 2685675520UL, 4294965248UL, "whois.apnic.net" },
/* 160.20.48.0 - 160.20.63.255 */
{ 2685677568UL, 4294963200UL, "whois.apnic.net" },
/* 160.20.64.0 - 160.20.71.255 */
{ 2685681664UL, 4294965248UL, "whois.lacnic.net" },
/* 160.20.72.0 - 160.20.75.255 */
{ 2685683712UL, 4294966272UL, "whois.apnic.net" },
/* 160.20.80.0 - 160.20.95.255 */
{ 2685685760UL, 4294963200UL, "whois.lacnic.net" },
/* 160.20.96.0 - 160.20.103.255 */
{ 2685689856UL, 4294965248UL, "whois.ripe.net" },
/* 160.20.108.0 - 160.20.111.255 */
{ 2685692928UL, 4294966272UL, "whois.ripe.net" },
/* 160.20.112.0 - 160.20.115.255 */
{ 2685693952UL, 4294966272UL, "whois.afrinic.net" },
/* 160.20.144.0 - 160.20.159.255 */
{ 2685702144UL, 4294963200UL, "whois.ripe.net" },
/* 160.20.160.0 - 160.20.207.255 */
{ 2685706240UL, 4294959104UL, "whois.lacnic.net" },
{ 2685714432UL, 4294963200UL, "whois.lacnic.net" },
/* 160.20.213.0 - 160.20.213.255 */
{ 2685719808UL, 4294967040UL, "whois.afrinic.net" },
/* 160.20.214.0 - 160.20.215.255 */
{ 2685720064UL, 4294966784UL, "whois.ripe.net" },
/* 160.20.217.0 - 160.20.217.255 */
{ 2685720832UL, 4294967040UL, "whois.afrinic.net" },
/* 160.20.218.0 - 160.20.219.255 */
{ 2685721088UL, 4294966784UL, "whois.lacnic.net" },
/* 160.20.221.0 - 160.20.221.255 */
{ 2685721856UL, 4294967040UL, "whois.afrinic.net" },
/* 160.20.222.0 - 160.20.223.255 */
{ 2685722112UL, 4294966784UL, "whois.apnic.net" },
/* 160.20.225.0 - 160.20.225.255 */
{ 2685722880UL, 4294967040UL, "whois.lacnic.net" },
/* 160.20.226.0 - 160.20.227.255 */
{ 2685723136UL, 4294966784UL, "whois.afrinic.net" },
/* 160.20.229.0 - 160.20.229.255 */
{ 2685723904UL, 4294967040UL, "whois.ripe.net" },
/* 160.20.242.0 - 160.20.243.255 */
{ 2685727232UL, 4294966784UL, "whois.lacnic.net" },
/* 160.20.246.0 - 160.20.247.255 */
{ 2685728256UL, 4294966784UL, "whois.lacnic.net" },
/* 160.20.248.0 - 160.20.249.255 */
{ 2685728768UL, 4294966784UL, "whois.ripe.net" },
/* 160.20.252.0 - 160.20.255.255 */
{ 2685729792UL, 4294966272UL, "whois.afrinic.net" },
/* 160.202.8.0 - 160.202.15.255 */
{ 2697594880UL, 4294965248UL, "whois.apnic.net" },
/* 160.202.16.0 - 160.202.31.255 */
{ 2697596928UL, 4294963200UL, "whois.ripe.net" },
/* 160.202.32.0 - 160.202.63.255 */
{ 2697601024UL, 4294959104UL, "whois.apnic.net" },
/* 160.202.128.0 - 160.202.255.255 */
{ 2697625600UL, 4294934528UL, "whois.apnic.net" },
/* 160.238.0.0 - 160.238.0.255 */
{ 2699952128UL, 4294967040UL, "whois.apnic.net" },
/* 160.238.11.0 - 160.238.11.255 */
{ 2699954944UL, 4294967040UL, "whois.afrinic.net" },
/* 160.238.12.0 - 160.238.19.255 */
{ 2699955200UL, 4294966272UL, "whois.apnic.net" },
{ 2699956224UL, 4294966272UL, "whois.apnic.net" },
/* 160.238.21.0 - 160.238.21.255 */
{ 2699957504UL, 4294967040UL, "whois.ripe.net" },
/* 160.238.24.0 - 160.238.29.255 */
{ 2699958272UL, 4294966272UL, "whois.lacnic.net" },
{ 2699959296UL, 4294966784UL, "whois.lacnic.net" },
/* 160.238.33.0 - 160.238.33.255 */
{ 2699960576UL, 4294967040UL, "whois.apnic.net" },
/* 160.238.34.0 - 160.238.35.255 */
{ 2699960832UL, 4294966784UL, "whois.apnic.net" },
/* 160.238.36.0 - 160.238.39.255 */
{ 2699961344UL, 4294966272UL, "whois.ripe.net" },
/* 160.238.48.0 - 160.238.49.255 */
{ 2699964416UL, 4294966784UL, "whois.afrinic.net" },
/* 160.238.50.0 - 160.238.50.255 */
{ 2699964928UL, 4294967040UL, "whois.afrinic.net" },
/* 160.238.52.0 - 160.238.55.255 */
{ 2699965440UL, 4294966272UL, "whois.ripe.net" },
/* 160.238.57.0 - 160.238.57.255 */
{ 2699966720UL, 4294967040UL, "whois.afrinic.net" },
/* 160.238.58.0 - 160.238.59.255 */
{ 2699966976UL, 4294966784UL, "whois.apnic.net" },
/* 160.238.60.0 - 160.238.61.255 */
{ 2699967488UL, 4294966784UL, "whois.ripe.net" },
/* 160.238.63.0 - 160.238.63.255 */
{ 2699968256UL, 4294967040UL, "whois.lacnic.net" },
/* 160.238.64.0 - 160.238.95.255 */
{ 2699968512UL, 4294959104UL, "whois.apnic.net" },
/* 160.238.96.0 - 160.238.99.255 */
{ 2699976704UL, 4294966272UL, "whois.ripe.net" },
/* 160.238.101.0 - 160.238.101.255 */
{ 2699977984UL, 4294967040UL, "whois.afrinic.net" },
/* 160.238.104.0 - 160.238.111.255 */
{ 2699978752UL, 4294965248UL, "whois.lacnic.net" },
/* 160.238.112.0 - 160.238.127.255 */
{ 2699980800UL, 4294963200UL, "whois.ripe.net" },
/* 160.238.128.0 - 160.238.255.255 */
{ 2699984896UL, 4294934528UL, "whois.lacnic.net" },
/* 161.123.0.0 - 161.123.255.255 */
{ 2709192704UL, 4294901760UL, "whois.afrinic.net" },
/* 162.12.196.0 - 162.12.199.255 */
{ 2718745600UL, 4294966272UL, "whois.lacnic.net" },
/* 162.12.200.0 - 162.12.207.255 */
{ 2718746624UL, 4294965248UL, "whois.ripe.net" },
/* 162.12.208.0 - 162.12.215.255 */
{ 2718748672UL, 4294965248UL, "whois.apnic.net" },
/* 162.12.240.0 - 162.12.247.255 */
{ 2718756864UL, 4294965248UL, "whois.apnic.net" },
/* 164.160.0.0 - 164.160.255.255 */
{ 2761949184UL, 4294901760UL, "whois.afrinic.net" },
/* 164.163.0.0 - 164.163.255.255 */
{ 2762145792UL, 4294901760UL, "whois.lacnic.net" },
/* 192.12.109.0 - 192.12.109.255 */
{ 3222039808UL, 4294967040UL, "whois.apnic.net" },
/* 192.12.110.0 - 192.12.111.255 */
{ 3222040064UL, 4294966784UL, "whois.afrinic.net" },
/* 192.12.112.0 - 192.12.115.255 */
{ 3222040576UL, 4294966272UL, "whois.lacnic.net" },
/* 192.12.116.0 - 192.12.117.255 */
{ 3222041600UL, 4294966784UL, "whois.afrinic.net" },
/* 192.12.118.0 - 192.12.118.255 */
{ 3222042112UL, 4294967040UL, "whois.lacnic.net" },
/* 192.26.110.0 - 192.26.110.255 */
{ 3222957568UL, 4294967040UL, "whois.apnic.net" },
/* 192.42.65.0 - 192.42.65.255 */
{ 3223994624UL, 4294967040UL, "whois.ripe.net" },
/* 192.47.36.0 - 192.47.36.255 */
{ 3224314880UL, 4294967040UL, "whois.afrinic.net" },
/* 192.51.188.0 - 192.51.188.255 */
{ 3224615936UL, 4294967040UL, "whois.apnic.net" },
/* 192.51.240.0 - 192.51.240.255 */
{ 3224629248UL, 4294967040UL, "whois.afrinic.net" },
/* 192.54.244.0 - 192.54.244.255 */
{ 3224826880UL, 4294967040UL, "whois.ripe.net" },
/* 192.67.23.0 - 192.67.23.255 */
{ 3225622272UL, 4294967040UL, "whois.lacnic.net" },
/* 192.68.185.0 - 192.68.185.255 */
{ 3225729280UL, 4294967040UL, "whois.lacnic.net" },
/* 192.70.192.0 - 192.70.199.255 */
{ 3225862144UL, 4294965248UL, "whois.ripe.net" },
/* 192.70.200.0 - 192.70.201.255 */
{ 3225864192UL, 4294966784UL, "whois.afrinic.net" },
/* 192.75.4.0 - 192.75.4.255 */
{ 3226141696UL, 4294967040UL, "whois.lacnic.net" },
/* 192.75.137.0 - 192.75.137.255 */
{ 3226175744UL, 4294967040UL, "whois.apnic.net" },
/* 192.75.236.0 - 192.75.236.255 */
{ 3226201088UL, 4294967040UL, "whois.afrinic.net" },
/* 192.83.207.0 - 192.83.207.255 */
{ 3226717952UL, 4294967040UL, "whois.lacnic.net" },
/* 192.83.208.0 - 192.83.215.255 */
{ 3226718208UL, 4294965248UL, "whois.afrinic.net" },
/* 192.83.216.0 - 192.83.216.255 */
{ 3226720256UL, 4294967040UL, "whois.ripe.net" },
/* 192.91.200.0 - 192.91.200.255 */
{ 3227240448UL, 4294967040UL, "whois.afrinic.net" },
/* 192.91.254.0 - 192.91.254.255 */
{ 3227254272UL, 4294967040UL, "whois.lacnic.net" },
/* 192.92.154.0 - 192.92.154.255 */
{ 3227294208UL, 4294967040UL, "whois.lacnic.net" },
/* 192.94.78.0 - 192.94.78.255 */
{ 3227405824UL, 4294967040UL, "whois.ripe.net" },
/* 192.135.90.0 - 192.135.91.255 */
{ 3230095872UL, 4294966784UL, "whois.apnic.net" },
/* 192.135.95.0 - 192.135.95.255 */
{ 3230097152UL, 4294967040UL, "whois.lacnic.net" },
/* 192.135.99.0 - 192.135.99.255 */
{ 3230098176UL, 4294967040UL, "whois.apnic.net" },
/* 192.135.100.0 - 192.135.100.255 */
{ 3230098432UL, 4294967040UL, "whois.ripe.net" },
/* 192.135.185.0 - 192.135.185.255 */
{ 3230120192UL, 4294967040UL, "whois.lacnic.net" },
/* 192.140.1.0 - 192.140.1.255 */
{ 3230400768UL, 4294967040UL, "whois.lacnic.net" },
/* 192.140.2.0 - 192.140.3.255 */
{ 3230401024UL, 4294966784UL, "whois.ripe.net" },
/* 192.140.8.0 - 192.140.15.255 */
{ 3230402560UL, 4294965248UL, "whois.lacnic.net" },
/* 192.140.16.0 - 192.140.127.255 */
{ 3230404608UL, 4294963200UL, "whois.lacnic.net" },
{ 3230408704UL, 4294959104UL, "whois.lacnic.net" },
{ 3230416896UL, 4294950912UL, "whois.lacnic.net" },
/* 192.140.128.0 - 192.140.255.255 */
{ 3230433280UL, 4294934528UL, "whois.apnic.net" },
/* 192.141.0.0 - 192.141.255.255 */
{ 3230466048UL, 4294901760UL, "whois.lacnic.net" },
/* 192.142.0.0 - 192.143.255.255 */
{ 3230531584UL, 4294836224UL, "whois.afrinic.net" },
/* 192.144.0.0 - 192.144.63.255 */
{ 3230662656UL, 4294950912UL, "whois.ripe.net" },
/* 192.144.64.0 - 192.144.71.255 */
{ 3230679040UL, 4294965248UL, "whois.lacnic.net" },
/* 192.144.72.0 - 192.144.73.255 */
{ 3230681088UL, 4294966784UL, "whois.lacnic.net" },
/* 192.144.75.0 - 192.144.75.255 */
{ 3230681856UL, 4294967040UL, "whois.ripe.net" },
/* 192.144.78.0 - 192.144.79.255 */
{ 3230682624UL, 4294966784UL, "whois.apnic.net" },
/* 192.144.80.0 - 192.144.95.255 */
{ 3230683136UL, 4294963200UL, "whois.apnic.net" },
/* 192.144.96.0 - 192.144.127.255 */
{ 3230687232UL, 4294959104UL, "whois.lacnic.net" },
/* 192.145.0.0 - 192.145.127.255 */
{ 3230728192UL, 4294934528UL, "whois.ripe.net" },
/* 192.145.128.0 - 192.145.191.255 */
{ 3230760960UL, 4294950912UL, "whois.afrinic.net" },
/* 192.145.192.0 - 192.145.223.255 */
{ 3230777344UL, 4294959104UL, "whois.lacnic.net" },
/* 192.145.224.0 - 192.145.227.255 */
{ 3230785536UL, 4294966272UL, "whois.ripe.net" },
/* 192.145.228.0 - 192.145.229.255 */
{ 3230786560UL, 4294966784UL, "whois.apnic.net" },
/* 192.145.230.0 - 192.145.230.255 */
{ 3230787072UL, 4294967040UL, "whois.afrinic.net" },
/* 192.153.12.0 - 192.153.12.255 */
{ 3231255552UL, 4294967040UL, "whois.lacnic.net" },
/* 192.156.144.0 - 192.156.144.255 */
{ 3231485952UL, 4294967040UL, "whois.apnic.net" },
/* 192.156.220.0 - 192.156.220.255 */
{ 3231505408UL, 4294967040UL, "whois.apnic.net" },
/* 192.172.232.0 - 192.172.232.255 */
{ 3232557056UL, 4294967040UL, "whois.ripe.net" },
/* 192.188.82.0 - 192.188.83.255 */
{ 3233567232UL, 4294966784UL, "whois.apnic.net" },
/* 192.188.248.0 - 192.188.248.255 */
{ 3233609728UL, 4294967040UL, "whois.ripe.net" },
/* 192.197.113.0 - 192.197.113.255 */
{ 3234164992UL, 4294967040UL, "whois.apnic.net" },
/* 192.251.230.0 - 192.251.230.255 */
{ 3237733888UL, 4294967040UL, "whois.ripe.net" },
/* 198.97.38.0 - 198.97.38.255 */
{ 3328255488UL, 4294967040UL, "whois.lacnic.net" },
/* 199.21.172.0 - 199.21.175.255 */
{ 3340086272UL, 4294966272UL, "whois.apnic.net" },
/* 199.212.57.0 - 199.212.57.255 */
{ 3352574208UL, 4294967040UL, "whois.apnic.net" },
/* 204.8.204.0 - 204.8.207.255 */
{ 3423128576UL, 4294966272UL, "whois.afrinic.net" },
/* 204.11.0.0 - 204.11.3.255 */
{ 3423272960UL, 4294966272UL, "whois.ripe.net" },
/* 204.48.32.0 - 204.48.33.255 */
{ 3425705984UL, 4294966784UL, "whois.ripe.net" },
/* 204.52.191.0 - 204.52.191.255 */
{ 3426008832UL, 4294967040UL, "whois.apnic.net" },
/* 204.225.42.0 - 204.225.43.255 */
{ 3437308416UL, 4294966784UL, "whois.lacnic.net" },
/* 205.211.83.0 - 205.211.83.255 */
{ 3453178624UL, 4294967040UL, "whois.ripe.net" },
/* 208.85.156.0 - 208.85.159.255 */
{ 3495271424UL, 4294966272UL, "whois.afrinic.net" },
/* 216.98.208.0 - 216.98.223.255 */
{ 3630354432UL, 4294963200UL, "whois.lacnic.net" },
/* 216.250.96.0 - 216.250.111.255 */
{ 3640287232UL, 4294963200UL, "whois.apnic.net" },
